@@ -4,7 +4,7 @@ test_that("plot_expirest_wisle_succeeds", {
   re1 <-
     expirest_wisle(
       data = exp2, response_vbl = "Related", time_vbl = "Month",
-      batch_vbl = "Batch", rl = 0.15, rl_sf = 3, sl = 0.3, sl_sf = 2,
+      batch_vbl = "Batch", rl = 0.15, rl_sf = 2, sl = 0.3, sl_sf = 1,
       srch_range = c(0, 500), alpha = 0.05, alpha_pool = 0.25,
       xform = c("no", "no"), shift = c(0, 0), sf_option = "loose",
       ivl = "confidence", ivl_type = "one.sided", ivl_side = "upper")
@@ -31,6 +31,14 @@ test_that("plot_expirest_wisle_succeeds", {
       srch_range = c(0, 500), alpha = 0.05, alpha_pool = 0.25,
       xform = c("no", "no"), shift = c(0, 0), sf_option = "tight",
       ivl = "confidence", ivl_type = "one.sided", ivl_side = "lower")
+  re5 <-
+    expirest_wisle(
+      data = exp2, response_vbl = "Related", time_vbl = "Month",
+      batch_vbl = "Batch", rl = seq(0.06, 0.18, 0.02), rl_sf = rep(3, 7),
+      sl = 0.3, sl_sf = 2, srch_range = c(0, 500), alpha = 0.05,
+      alpha_pool = 0.25, xform = c("no", "no"), shift = c(0, 0),
+      sf_option = "tight", ivl = "confidence", ivl_type = "one.sided",
+      ivl_side = "upper")
 
   # <-><-><-><->
 
@@ -38,68 +46,80 @@ test_that("plot_expirest_wisle_succeeds", {
     plot_expirest_wisle(
       model = re1, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = "%", y_range = c(-0.01, 0.50),
-      x_range = NULL, scenario = "standard", plot_option = "full",
-      ci_app = "line")
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "line")
   tmp2 <-
     plot_expirest_wisle(
       model = re2, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = " mg/kg", y_range = c(92, 107),
-      x_range = c(-1, 29), scenario = "standard", plot_option = "full",
-      ci_app = "line")
+      x_range = c(-1, 29), scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "line")
   tmp3stsc <-
     plot_expirest_wisle(
       model = re2, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(92, 107),
-      x_range = c(-1, 29), scenario = "standard", plot_option = "full",
-      ci_app = "ribbon")
+      x_range = c(-1, 29), scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "ribbon")
   tmp3wcsc <-
     plot_expirest_wisle(
       model = re2, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(92, 107),
-      x_range = NULL, scenario = "worst", plot_option = "full",
-      ci_app = "ribbon")
-  tmp4 <-
-    plot_expirest_wisle(
-      model = re2, rl_index = 1, show_grouping = "no",
-      response_vbl_unit = NULL, y_range = c(92, 107),
-      x_range = c(-1, 29), scenario = "standard",
+      x_range = NULL, scenario = "worst", mtbs = "verified",
       plot_option = "full", ci_app = "ribbon")
-  tmp4l1 <-
+  suppressWarnings(tmp4 <-
     plot_expirest_wisle(
       model = re2, rl_index = 1, show_grouping = "no",
       response_vbl_unit = NULL, y_range = c(92, 107),
-      x_range = c(-1, 29), scenario = "standard",
-      plot_option = "lean1", ci_app = "ribbon")
-  tmp4l2 <-
+      x_range = c(-1, 29), scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "ribbon"))
+  suppressWarnings(tmp4l1 <-
     plot_expirest_wisle(
       model = re2, rl_index = 1, show_grouping = "no",
       response_vbl_unit = NULL, y_range = c(92, 107),
-      x_range = c(-1, 29), scenario = "standard",
-      plot_option = "lean2", ci_app = "ribbon")
-  tmp4b1 <-
+      x_range = c(-1, 29), scenario = "standard", mtbs = "verified",
+      plot_option = "lean1", ci_app = "ribbon"))
+  suppressWarnings(tmp4l2 <-
     plot_expirest_wisle(
       model = re2, rl_index = 1, show_grouping = "no",
       response_vbl_unit = NULL, y_range = c(92, 107),
-      x_range = c(-1, 29), scenario = "standard",
-      plot_option = "basic1", ci_app = "ribbon")
-  tmp4b2 <-
+      x_range = c(-1, 29), scenario = "standard", mtbs = "verified",
+      plot_option = "lean2", ci_app = "ribbon"))
+  suppressWarnings(tmp4b1 <-
     plot_expirest_wisle(
       model = re2, rl_index = 1, show_grouping = "no",
       response_vbl_unit = NULL, y_range = c(92, 107),
-      x_range = c(-1, 29), scenario = "standard",
-      plot_option = "basic2", ci_app = "ribbon")
-  tmp5 <-
+      x_range = c(-1, 29), scenario = "standard", mtbs = "verified",
+      plot_option = "basic1", ci_app = "ribbon"))
+  suppressWarnings(tmp4b2 <-
+    plot_expirest_wisle(
+      model = re2, rl_index = 1, show_grouping = "no",
+      response_vbl_unit = NULL, y_range = c(92, 107),
+      x_range = c(-1, 29), scenario = "standard", mtbs = "verified",
+      plot_option = "basic2", ci_app = "ribbon"))
+  suppressWarnings(tmp5 <-
     plot_expirest_wisle(
       model = re3, rl_index = 1, show_grouping = "no",
       response_vbl_unit = "% (w/w)", y_range = c(0.2, 5.2),
-      x_range = NULL, scenario = "standard", plot_option = "full",
-      ci_app = "line")
-  tmp6 <-
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "line"))
+  suppressWarnings(tmp6 <-
     plot_expirest_wisle(
       model = re4, rl_index = 1, show_grouping = "no",
       response_vbl_unit = "% (w/w)", y_range = c(0.2, 5.2),
-      x_range = NULL, scenario = "standard", plot_option = "full",
-      ci_app = "line")
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "line"))
+  suppressWarnings(tmp7 <-
+    plot_expirest_wisle(
+      model = re4, rl_index = 1, show_grouping = "no",
+      response_vbl_unit = "% (w/w)", y_range = NULL,
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "line"))
+  tmp8 <-
+    plot_expirest_wisle(
+      model = re5, rl_index = 7, show_grouping = "yes",
+      response_vbl_unit = "%", y_range = c(-0.01, 0.50),
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "ribbon")
 
   # <-><-><-><->
 
@@ -111,9 +131,9 @@ test_that("plot_expirest_wisle_succeeds", {
   expect_equal(signif(tmp1[["text"]][, "Related"], 5),
                c(0.35000, 0.29822, 0.11222, 0.39000, 0.39000, 0.16400))
   expect_equal(tmp1[["text"]][, "Label"],
-               c("USL: 0.340%", "0.2982% ", "0.1122% ",
-                 "15.7\n(worst case scenario)", "19.0\n(standard scenario)",
-                 "URL: 0.1540%"))
+               c("USL: 0.34%", "0.298% ", "0.112% ",
+                 "15.7\n(worst case\nscenario)", "19.0\n(standard\nscenario)",
+                 "URL: 0.154%"))
   expect_equal(tmp1[["text"]][, "Colour"],
                c("black", "red", "royalblue", "forestgreen", "grey50", "grey0"))
 
@@ -166,7 +186,7 @@ test_that("plot_expirest_wisle_succeeds", {
   expect_equal(tmp2[["text"]][, "Label"],
                c("LSL: 94.95 mg/kg", "USL: 105.04 mg/kg", "98.405 mg/kg ",
                  "100.45 mg/kg",
-                 "7.5\n(worst case scenario)", "23.7\n(standard scenario)",
+                 "7.5\n(worst case\nscenario)", "23.7\n(standard\nscenario)",
                  "LRL: 96.995 mg/kg"))
   expect_equal(tmp2[["text"]][, "Colour"],
                c("black", "black", "red", "royalblue", "forestgreen",
@@ -214,7 +234,7 @@ test_that("plot_expirest_wisle_succeeds", {
   expect_length(tmp3stsc[["Graph"]]$labels, 11)
   expect_equal(tmp3stsc[["text"]][, "Label"],
                c("LSL: 94.95", "USL: 105.04", "98.405 ", "100.45",
-                 "7.5\n(worst case scenario)", "23.7\n(standard scenario)",
+                 "7.5\n(worst case\nscenario)", "23.7\n(standard\nscenario)",
                  "LRL: 96.995"))
   expect_equal(signif(tmp3stsc[["text"]][, "Month"], 5),
                c(29.000, 29.0000, 0.00000, 0.00000, 7.5187, 23.698, 29.000))
@@ -222,7 +242,7 @@ test_that("plot_expirest_wisle_succeeds", {
   expect_length(tmp3wcsc[["Graph"]]$labels, 11)
   expect_equal(tmp3wcsc[["text"]][, "Label"],
                c("LSL: 94.95", "USL: 105.04", "98.405 ", "100.45",
-                 "7.5\n(worst case scenario)", "23.7\n(standard scenario)",
+                 "7.5\n(worst case\nscenario)", "23.7\n(standard\nscenario)",
                  "LRL: 96.995"))
   expect_equal(signif(tmp3wcsc[["text"]][, "Month"], 5),
                c(10.000, 10.0000, 0.00000, 0.00000, 7.5187, 23.698, 10.000))
@@ -230,12 +250,12 @@ test_that("plot_expirest_wisle_succeeds", {
   expect_length(tmp4[["Graph"]]$labels, 8)
   expect_equal(tmp4[["text"]][, "Label"],
                c("LSL: 94.95", "USL: 105.04", "99.861 ", "101.91",
-                 "8.3\n(worst case scenario)", "30.2\n(standard scenario)",
+                 "8.3\n(worst case\nscenario)", "30.2\n(standard\nscenario)",
                  "LRL: 96.995"))
   expect_length(tmp4l1[["Graph"]]$labels, 8)
   expect_equal(tmp4l1[["text"]][, "Label"],
                c("LSL: 94.95", "USL: 105.04", "99.861 ", "101.91",
-                 "8.3\n(worst case scenario)", "30.2\n(standard scenario)",
+                 "8.3\n(worst case\nscenario)", "30.2\n(standard\nscenario)",
                  "LRL: 96.995"))
   expect_length(tmp4l2[["Graph"]]$labels, 8)
   expect_equal(tmp4l2[["text"]][, "Label"],
@@ -244,12 +264,12 @@ test_that("plot_expirest_wisle_succeeds", {
   expect_length(tmp4b1[["Graph"]]$labels, 5)
   expect_equal(tmp4b1[["text"]][, "Label"],
                c("LSL: 94.95", "USL: 105.04", "99.861 ", "101.91",
-                 "8.3\n(worst case scenario)", "30.2\n(standard scenario)",
+                 "8.3\n(worst case\nscenario)", "30.2\n(standard\nscenario)",
                  "LRL: 96.995"))
   expect_length(tmp4b2[["Graph"]]$labels, 5)
   expect_equal(tmp4b2[["text"]][, "Label"],
                c("LSL: 94.95", "USL: 105.04", "99.861 ", "101.91",
-                 "8.3\n(worst case scenario)", "30.2\n(standard scenario)",
+                 "8.3\n(worst case\nscenario)", "30.2\n(standard\nscenario)",
                  "LRL: 96.995"))
 
   expect_equal(signif(tmp5[["text"]][, "Month"], 5),
@@ -259,7 +279,7 @@ test_that("plot_expirest_wisle_succeeds", {
   expect_equal(tmp5[["text"]][, "Label"],
                c("LSL: 0.5% (w/w)", "USL: 4.5% (w/w)", "3.96% (w/w) ",
                  "2.46% (w/w)",
-                 "72.5\n(worst case scenario)", "96.3\n(standard scenario)",
+                 "72.5\n(worst case\nscenario)", "96.3\n(standard\nscenario)",
                  "URL: 3.00% (w/w)"))
   expect_equal(tmp5[["text"]][, "Colour"],
                c("black", "black", "red", "royalblue", "forestgreen",
@@ -310,7 +330,7 @@ test_that("plot_expirest_wisle_succeeds", {
                c(1.4000, 0.95678, 2.4568, 1.0000, 1.0000, 2.9000))
   expect_equal(tmp6[["text"]][, "Label"],
                c("LSL: 1.5% (w/w)", "0.957% (w/w) ", "2.46% (w/w) ",
-                 "90.5\n(worst case scenario)", "60.8\n(standard scenario)",
+                 "90.5\n(worst case\nscenario)", "60.8\n(standard\nscenario)",
                  "LRL: 3.00% (w/w)"))
   expect_equal(tmp6[["text"]][, "Colour"],
                c("black", "red", "royalblue", "forestgreen",
@@ -354,6 +374,108 @@ test_that("plot_expirest_wisle_succeeds", {
   expect_equal(tmp6[["arrow"]][1, "Curvature"], 0.5)
   expect_equal(tmp6[["arrow"]][1, "Angle"], 90)
   expect_equal(tmp6[["arrow"]][1, "Length"], 7)
+
+  expect_equal(signif(tmp7[["text"]][, "Month"], 5),
+               c(70.000, 0.00000, 0.00000, 90.540, 60.761, 70.000))
+  expect_equal(signif(tmp7[["text"]][, "Moisture"], 5),
+               c(1.4000, 0.95678, 2.4568, 1.0000, 1.0000, 2.9000))
+  expect_equal(tmp7[["text"]][, "Label"],
+               c("LSL: 1.5% (w/w)", "0.957% (w/w) ", "2.46% (w/w) ",
+                 "90.5\n(worst case\nscenario)", "60.8\n(standard\nscenario)",
+                 "LRL: 3.00% (w/w)"))
+  expect_equal(tmp7[["text"]][, "Colour"],
+               c("black", "red", "royalblue", "forestgreen",
+                 "grey50", "grey0"))
+
+  expect_equal(tmp7[["hlines"]][, "Moisture"], 1.5)
+  expect_equal(tmp7[["hlines"]][, "Item"], "LSL")
+  expect_equal(tmp7[["hlines"]][, "Colour"], "black")
+  expect_equal(tmp7[["hlines"]][, "Type"], "dotted")
+
+  expect_equal(signif(tmp7[["vlines"]][, "Month"], 5), c(90.540, 60.761))
+  expect_equal(tmp7[["vlines"]][, "Item"], c("poi.woca", "poi.model"))
+  expect_equal(tmp7[["vlines"]][, "Colour"], c("forestgreen", "grey50"))
+  expect_equal(tmp7[["vlines"]][, "Type"], c("dashed", "dotdash"))
+
+  expect_equal(signif(tmp7[["segments"]][, "Month.1"], 5),
+               c(0.00000, 0.00000, -1.0000, -0.33333))
+  expect_equal(signif(tmp7[["segments"]][, "Month.2"], 5),
+               c(90.540, 70.000, -1.0000, -0.33333))
+  expect_equal(signif(tmp7[["segments"]][, "Moisture.1"], 5),
+               c(0.95678, 3.0000, 1.5000, 0.95678))
+  expect_equal(signif(tmp7[["segments"]][, "Moisture.2"], 5),
+               c(0.95678, 3.0000, 3.0000, 2.4568))
+  expect_equal(tmp7[["segments"]][, "Item"],
+               c("x.delta", "x.delta.shifted", "y.delta", "y.delta.shifted"))
+  expect_equal(tmp7[["segments"]][, "Colour"],
+               c("red", "grey0", "grey50", "grey50"))
+  expect_equal(tmp7[["segments"]][, "Type"],
+               c("dashed", "dotted", "solid", "solid"))
+  expect_equal(tmp7[["segments"]][, "Size"], c(0.5, 0.5, 1.0, 1.0))
+
+  expect_equal(signif(tmp7[["arrow"]][, "Month.1"], 5), -0.33333)
+  expect_equal(signif(tmp7[["arrow"]][, "Month.2"], 5), -1.5000)
+  expect_equal(signif(tmp7[["arrow"]][, "Moisture.1"], 5), 1.7068)
+  expect_equal(signif(tmp7[["arrow"]][, "Moisture.2"], 5), 2.2500)
+  expect_equal(tmp7[["arrow"]][1, "Item"], "arrow")
+  expect_equal(tmp7[["arrow"]][1, "Colour"], "grey50")
+  expect_equal(tmp7[["arrow"]][1, "Line.Type"], "solid")
+  expect_equal(tmp7[["arrow"]][1, "Arrow.Type"], "closed")
+  expect_equal(tmp7[["arrow"]][1, "Size"], 0.5)
+  expect_equal(tmp7[["arrow"]][1, "Curvature"], 0.5)
+  expect_equal(tmp7[["arrow"]][1, "Angle"], 90)
+  expect_equal(tmp7[["arrow"]][1, "Length"], 7)
+
+  expect_equal(signif(tmp8[["text"]][, "Month"], 5),
+               c(20.000,  0.00000,  0.00000, 10.303, 15.845, 20.000))
+  expect_equal(signif(tmp8[["text"]][, "Related"], 5),
+               c(0.31000, 0.23222, 0.11222, 0.35000, 0.35000, 0.19000))
+  expect_equal(tmp8[["text"]][, "Label"],
+               c("USL: 0.30%", "0.232% ", "0.112% " ,
+                 "10.3\n(worst case\nscenario)", "15.8\n(standard\nscenario)",
+                 "URL: 0.180%"))
+  expect_equal(tmp8[["text"]][, "Colour"],
+               c("black", "red", "royalblue", "forestgreen",
+                 "grey50", "grey0"))
+
+  expect_equal(tmp8[["hlines"]][, "Related"], 0.30)
+  expect_equal(tmp8[["hlines"]][, "Item"], "USL")
+  expect_equal(tmp8[["hlines"]][, "Colour"], "black")
+  expect_equal(tmp8[["hlines"]][, "Type"], "dotted")
+
+  expect_equal(signif(tmp8[["vlines"]][, "Month"], 5), c(10.303, 15.845))
+  expect_equal(tmp8[["vlines"]][, "Item"], c("poi.woca", "poi.model"))
+  expect_equal(tmp8[["vlines"]][, "Colour"], c("forestgreen", "grey50"))
+  expect_equal(tmp8[["vlines"]][, "Type"], c("dashed", "dotdash"))
+
+  expect_equal(signif(tmp8[["segments"]][, "Month.1"], 5),
+               c(0.00000, 0.00000, -0.33333, -0.11111))
+  expect_equal(signif(tmp8[["segments"]][, "Month.2"], 5),
+               c(10.303, 20.000, -0.33333, -0.11111))
+  expect_equal(signif(tmp8[["segments"]][, "Related.1"], 5),
+               c(0.23222, 0.18000, 0.30000, 0.23222))
+  expect_equal(signif(tmp8[["segments"]][, "Related.2"], 5),
+               c(0.23222, 0.18000, 0.18000, 0.11222))
+  expect_equal(tmp8[["segments"]][, "Item"],
+               c("x.delta", "x.delta.shifted", "y.delta", "y.delta.shifted"))
+  expect_equal(tmp8[["segments"]][, "Colour"],
+               c("red", "grey0", "grey50", "grey50"))
+  expect_equal(tmp8[["segments"]][, "Type"],
+               c("dashed", "dotted", "solid", "solid"))
+  expect_equal(tmp8[["segments"]][, "Size"], c(0.5, 0.5, 1.0, 1.0))
+
+  expect_equal(signif(tmp8[["arrow"]][, "Month.1"], 5), -0.11111)
+  expect_equal(signif(tmp8[["arrow"]][, "Month.2"], 5), -0.5)
+  expect_equal(signif(tmp8[["arrow"]][, "Related.1"], 5), 0.17222)
+  expect_equal(signif(tmp8[["arrow"]][, "Related.2"], 5), 0.24000)
+  expect_equal(tmp8[["arrow"]][1, "Item"], "arrow")
+  expect_equal(tmp8[["arrow"]][1, "Colour"], "grey50")
+  expect_equal(tmp8[["arrow"]][1, "Line.Type"], "solid")
+  expect_equal(tmp8[["arrow"]][1, "Arrow.Type"], "closed")
+  expect_equal(tmp8[["arrow"]][1, "Size"], 0.5)
+  expect_equal(tmp8[["arrow"]][1, "Curvature"], -0.5)
+  expect_equal(tmp8[["arrow"]][1, "Angle"], 90)
+  expect_equal(tmp8[["arrow"]][1, "Length"], 5)
 })
 
 test_that("plot_expirest_wisle_succeeds_with_transformations", {
@@ -434,57 +556,57 @@ test_that("plot_expirest_wisle_succeeds_with_transformations", {
     plot_expirest_wisle(
       model = re1, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = "%", y_range = c(-0.01, 0.50),
-      x_range = NULL, scenario = "standard", plot_option = "full",
-      ci_app = "line")
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "line")
   tmp2 <-
     plot_expirest_wisle(
       model = re2, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = "%", y_range = c(-0.01, 0.50),
-      x_range = NULL, scenario = "standard", plot_option = "full",
-      ci_app = "line")
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "line")
   tmp3 <-
     plot_expirest_wisle(
       model = re3, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = "%", y_range = c(-0.01, 0.50),
-      x_range = NULL, scenario = "standard", plot_option = "full",
-      ci_app = "line")
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "line")
 
-  tmp4 <-
+  suppressWarnings(tmp4 <-
     plot_expirest_wisle(
       model = re4, rl_index = 1, show_grouping = "no",
       response_vbl_unit = "% (w/w)", y_range = c(0.2, 5.2),
-      x_range = NULL, scenario = "standard", plot_option = "full",
-      ci_app = "line")
-  tmp5 <-
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "line"))
+    suppressWarnings(tmp5 <-
     plot_expirest_wisle(
       model = re5, rl_index = 1, show_grouping = "no",
       response_vbl_unit = "% (w/w)", y_range = c(0.2, 5.2),
-      x_range = NULL, scenario = "standard", plot_option = "full",
-      ci_app = "ribbon")
-  tmp6 <-
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "ribbon"))
+    suppressWarnings(tmp6 <-
     plot_expirest_wisle(
       model = re6, rl_index = 1, show_grouping = "no",
       response_vbl_unit = "% (w/w)", y_range = c(0.2, 5.2),
-      x_range = NULL, scenario = "standard", plot_option = "full",
-      ci_app = "ribbon")
-  tmp7 <-
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "full", ci_app = "ribbon"))
+    suppressWarnings(tmp7 <-
     plot_expirest_wisle(
       model = re7, rl_index = 1, show_grouping = "no",
       response_vbl_unit = "% (w/w)", y_range = c(0.2, 5.2),
-      x_range = NULL, scenario = "standard", plot_option = "lean1",
-      ci_app = "line")
-  tmp8 <-
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "lean1", ci_app = "line"))
+    suppressWarnings(tmp8 <-
     plot_expirest_wisle(
       model = re8, rl_index = 1, show_grouping = "no",
       response_vbl_unit = "% (w/w)", y_range = c(0.2, 5.2),
-      x_range = NULL, scenario = "standard", plot_option = "lean1",
-      ci_app = "ribbon")
-  tmp9 <-
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "lean1", ci_app = "ribbon"))
+    suppressWarnings(tmp9 <-
     plot_expirest_wisle(
       model = re9, rl_index = 1, show_grouping = "no",
       response_vbl_unit = "% (w/w)", y_range = c(0.2, 5.2),
-      x_range = NULL, scenario = "standard", plot_option = "lean1",
-      ci_app = "ribbon")
+      x_range = NULL, scenario = "standard", mtbs = "verified",
+      plot_option = "lean1", ci_app = "ribbon"))
 
   # <-><-><-><->
 
@@ -585,25 +707,29 @@ test_that("plot_expirest_wisle_fails", {
     plot_expirest_wisle(
       model = ree, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(93, 107), x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "model must be an object of class expirest_wisle")
   expect_error(
     plot_expirest_wisle(
       model = re1, rl_index = "x", show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(93, 107), x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "rl_index must be a positive integer of length 1")
   expect_error(
     plot_expirest_wisle(
       model = re1, rl_index = 1.1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(93, 107), x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "rl_index must be a positive integer of length 1")
   expect_error(
     plot_expirest_wisle(
       model = re1, rl_index = c(1, 2), show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(93, 107), x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "rl_index must be a positive integer of length 1")
   expect_error(
     plot_expirest_wisle(
@@ -615,78 +741,77 @@ test_that("plot_expirest_wisle_fails", {
     plot_expirest_wisle(
       model = re1, rl_index = 2, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(93, 107), x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "rl_index must be between 1 and the number of rl values")
-  expect_error(
-    plot_expirest_wisle(
-      model = re1, rl_index = 1, show_grouping = "incorrect",
-      response_vbl_unit = NULL, y_range = c(93, 107), x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
-    "specify show_grouping either as \"yes\" or \"no\"")
   expect_error(
     plot_expirest_wisle(
       model = re1, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = 1, y_range = c(93, 107), x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "response_vbl_unit must be a string")
   expect_error(
     plot_expirest_wisle(
       model = re1, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = "range", x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "y_range must be a vector of length 2")
   expect_error(
     plot_expirest_wisle(
       model = re1, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = 107, x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "y_range must be a vector of length 2")
-  expect_error(
-    plot_expirest_wisle(
-      model = re1, rl_index = 1, show_grouping = "yes",
-      response_vbl_unit = NULL, y_range = c(107, 93), x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
-    "y_range must be of the form")
   expect_error(
     plot_expirest_wisle(
       model = re1, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(93, 107), x_range = "range",
-      scenario = "standard", plot_option = "full", ci_app = "line"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "x_range must be a vector of length 2")
   expect_error(
     plot_expirest_wisle(
       model = re1, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(93, 107), x_range = 36,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "x_range must be a vector of length 2")
-  expect_error(
-    plot_expirest_wisle(
-      model = re1, rl_index = 1, show_grouping = "yes",
-      response_vbl_unit = NULL, y_range = c(93, 107), x_range = c(36, 0),
-      scenario = "standard", plot_option = "full", ci_app = "line"),
-    "x_range must be of the form")
   expect_error(
     plot_expirest_wisle(
       model = re1, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(93, 107), x_range = NULL,
-      scenario = "incorrect", plot_option = "full", ci_app = "line"),
+      scenario = "incorrect", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "specify scenario either as \"standard\" or \"worst\"")
   expect_error(
     plot_expirest_wisle(
       model = re1, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(93, 107), x_range = NULL,
-      scenario = "standard", plot_option = "incorrect", ci_app = "line"),
+      scenario = "standard", mtbs = "incorrect", plot_option = "full",
+      ci_app = "line"),
+    "specify mtbs either as \"verified\", \"cics\", \"dics\", ")
+  expect_error(
+    plot_expirest_wisle(
+      model = re1, rl_index = 1, show_grouping = "yes",
+      response_vbl_unit = NULL, y_range = c(93, 107), x_range = NULL,
+      scenario = "standard", mtbs = "verified", plot_option = "incorrect",
+      ci_app = "line"),
     "specify plot_option either as \"full\", \"lean1\"")
   expect_error(
     plot_expirest_wisle(
       model = re1, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(93, 107), x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "points"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "points"),
     "specify ci_app either as \"line\" or \"ribbon\"")
   expect_error(
     plot_expirest_wisle(
       model = re2, rl_index = 1, show_grouping = "yes",
       response_vbl_unit = NULL, y_range = c(93, 107), x_range = NULL,
-      scenario = "standard", plot_option = "full", ci_app = "line"),
+      scenario = "standard", mtbs = "verified", plot_option = "full",
+      ci_app = "line"),
     "Expiry determination was not successful")
 })
